/// <reference types="node" />
import { IndexableDocument, DocumentCollatorFactory } from '@backstage/plugin-search-common';
import { Config } from '@backstage/config';
import { Readable } from 'stream';
import * as _backstage_backend_plugin_api from '@backstage/backend-plugin-api';
import { LoggerService } from '@backstage/backend-plugin-api';

/**
 * Extended IndexableDocument with stack overflow specific properties
 *
 * @public
 */
interface StackOverflowDocument extends IndexableDocument {
    answers: number;
    tags: string[];
}
/**
 * Type representing the request parameters accepted by the {@link StackOverflowQuestionsCollatorFactory}
 *
 * @public
 */
type StackOverflowQuestionsRequestParams = {
    [key: string]: string | string[] | number;
};
/**
 * Options for {@link StackOverflowQuestionsCollatorFactory}
 *
 * @public
 */
type StackOverflowQuestionsCollatorFactoryOptions = {
    baseUrl?: string;
    maxPage?: number;
    apiKey?: string;
    apiAccessToken?: string;
    teamName?: string;
    requestParams?: StackOverflowQuestionsRequestParams;
    logger: LoggerService;
};
/**
 * Search collator responsible for collecting stack overflow questions to index.
 *
 * @public
 */
declare class StackOverflowQuestionsCollatorFactory implements DocumentCollatorFactory {
    protected requestParams: StackOverflowQuestionsRequestParams;
    private readonly baseUrl;
    private readonly apiKey;
    private readonly apiAccessToken;
    private readonly teamName;
    private readonly maxPage;
    private readonly logger;
    readonly type: string;
    private constructor();
    static fromConfig(config: Config, options: StackOverflowQuestionsCollatorFactoryOptions): StackOverflowQuestionsCollatorFactory;
    getCollator(): Promise<Readable>;
    execute(): AsyncGenerator<StackOverflowDocument>;
}

/**
 * @public
 * Search backend module for the Stack Overflow index.
 */
declare const searchStackOverflowCollatorModule: _backstage_backend_plugin_api.BackendFeature;

export { type StackOverflowDocument, StackOverflowQuestionsCollatorFactory, type StackOverflowQuestionsCollatorFactoryOptions, type StackOverflowQuestionsRequestParams, searchStackOverflowCollatorModule as default };
